@@ -10,12 +10,13 @@
 #' @return Optional: names of estimator.
 #' @author TszKin Julian Chan \email{ctszkin@@gmail.com}
 #' @seealso \code{\link{ezsim}}
-#' @S3method test ezsim
+#' @export 
 #' @examples         
 #' \dontrun{ 
 #' ezsim_basic<-ezsim(
 #'     m             = 100,
 #'     run           = FALSE,
+#'     run_test      = FALSE,
 #'     display_name  = c(mean_hat="hat(mu)",sd_mean_hat="hat(sigma[hat(mu)])"),
 #'     parameter_def = createParDef(list(n=seq(20,80,20),mu=c(0,2),sigma=c(1,3,5))),
 #'     dgp           = function() rnorm(n,mu,sigma),
@@ -30,12 +31,25 @@ test.ezsim <-
 function(x,return_name=TRUE,print_result=FALSE,...){
 	parameter_list <- generate(x$parameter_def)
 	
+	## Decide whether we need to stop the cluster after the test
 	create_cluster_flag <- FALSE
 	
-	if (x$parallel & is.null(x$cluster)){ 
-		x$cluster<-makeCluster(x$number_of_workers)
+	if (x$use_core > 1 & is.null(x$cluster) ){
+		x$cluster <- makeCluster(x$use_core)
+		if (!is.null(x$cluster_packages)){
+			for (i in 1:length(x$cluster_packages))
+				eval(substitute( 
+					clusterEvalQ(x$cluster , require(w, character.only=TRUE)   )  ,
+					list( w=x$cluster_packages[i] )
+				))
+		}
+		clusterSetRNGStream(x$cluster,x$use_seed)
 		create_cluster_flag<-TRUE
 	}
+
+	if (x$use_core == 1) 
+		set.seed(x$use_seed)
+
 	i=NULL
 	tryCatch({
 		## test for estimator
